@@ -5,7 +5,8 @@
         ReplaceByFile：通过正则匹配 url，使用文件替换整个响应
         ReplaceByStr：通过正则匹配 url，使用字典替换部分字段
 """
-from typing import Dict
+import re
+from typing import Dict, Union
 from loguru import logger
 from mitmproxy import http
 from mitmtools.base import MitmproxyBase
